@@ -32,4 +32,4 @@ def main(fileName):
     #traverse(tree, parser.ruleNames)
 
 if __name__ == '__main__':
-    main("./Examples/test.txt")
\ No newline at end of file
+    main("./Examples/test.py")
\ No newline at end of file
